@@ -13,20 +13,20 @@ my $plot = IUP::PPlot->new(
              AXS_XLABEL   => "X",
              AXS_YLABEL   => "Y",
              AXS_YMIN     => -1.1,
-	     AXS_YAUTOMIN => "NO",
+             AXS_YAUTOMIN => "NO",
              AXS_YMAX     => 1.1,
-	     AXS_YAUTOMAX => "NO",
+             AXS_YAUTOMAX => "NO",
 );
 
-$plot->PlotBegin(0);
+$plot->PlotBegin(2);
 for (my $x=-2; $x<=2; $x+=0.01) {
-  $plot->PlotAdd($x, sin($x))
+  $plot->PlotAdd2D($x, sin($x))
 }
 $plot->PlotEnd();
 
-$plot->PlotBegin(0);
+$plot->PlotBegin(2);
 for (my $x=-2; $x<=2; $x+=0.01) {
-  $plot->PlotAdd($x, cos($x))
+  $plot->PlotAdd2D($x, cos($x))
 }
 $plot->PlotEnd();
 
