@@ -3,11 +3,9 @@ use strict;
 use warnings;
 use base 'IUP::Internal::Element';
 use IUP::Internal::LibraryIup;
-use Carp;
 
 sub _create_element {
-  my ($self, $args) = @_;
-  return IUP::Internal::LibraryIup::_IupExpander($args->{child});
+  return shift->_proc_child_param(\&IUP::Internal::LibraryIup::_IupExpander, @_);
 }
 
 1;
