@@ -8,11 +8,10 @@ sub _create_element {
   my ($self, $args, $firstonly) = @_;
   my $ih;
   if (defined $firstonly) {
-    $ih = IUP::Internal::LibraryIup::_IupVal($args->{type});
+    $ih = IUP::Internal::LibraryIup::_IupVal($firstonly);
   }
-  elsif (defined $args && defined $args->{type}) {
-    $ih = IUP::Internal::LibraryIup::_IupVal($args->{type});
-    delete $args->{type};
+  elsif (defined $args->{type}) {
+    $ih = IUP::Internal::LibraryIup::_IupVal(delete $args->{type});
   }
   else {
     $ih = IUP::Internal::LibraryIup::_IupVal(undef);
